@@ -2,6 +2,5 @@
 
 GPipe::~GPipe()
 {
-    close(readFd());
-    close(writeFd());
+    close();
 }
